@@ -1,13 +1,11 @@
-PYRONE_VERSION = '0.2.16'
-
 from pyramid.config import Configurator
-from pyramid.authentication import SessionAuthenticationPolicy
+#from pyramid.authentication import SessionAuthenticationPolicy
 from pyramid.authorization import ACLAuthorizationPolicy
 from pyramid_beaker import session_factory_from_settings
 from sqlalchemy import engine_from_config
 
 from pyrone.models import initialize_sql
-from pyrone.lib.auth import PyroneSessionAuthenticationPolicy
+from pyrone.lib.auth import PyroneSessionAuthenticationPolicy, get_user
 from pyrone.models.file import init_storage_from_settings
 from pyrone.lib.notifications import init_notifications_from_settings
 from pyrone.lib.lang import locale_negotiator
@@ -29,6 +27,7 @@ def main(global_config, **settings):
         authorization_policy=authorization_policy,
         locale_negotiator=locale_negotiator)
     config.add_translation_dirs('pyrone:locale/')
+    config.set_request_property(get_user, 'user', reify=True) # reify=True means that result is cached per request
     config.scan()
     config.add_static_view('static', 'pyrone:static')
     routes = [
@@ -54,7 +53,6 @@ def main(global_config, **settings):
               
               ('account_my_profile', '/me'),
               ('account_save_my_profile_ajax', '/me/save/ajax'),
-              ('account_login_form', '/login'),
               ('account_login', '/login'),
               ('account_logout', '/logout'),
               ('account_verify_email', '/verify-email'),
