@@ -2,6 +2,7 @@
 import logging
 import transaction
 import shutil
+import base64
 import os
 import zipfile
 from pyramid.security import forget
@@ -10,13 +11,14 @@ from datetime import datetime
 
 from base64 import b64encode, b64decode
 from mimetypes import guess_type
+from pyramid.response import Response
 from pyramid.view import view_config
 from pyramid.url import route_url
 from pyramid.httpexceptions import HTTPBadRequest, HTTPFound, HTTPNotFound
 from sqlalchemy.exc import IntegrityError
 
 from pyrone.lib import helpers as h, auth, markup
-from pyrone.models import config, DBSession, Article, Comment, Tag, File, Config, User, Permission, VerifiedEmail
+from pyrone.models import config, DBSession, Article, Comment, Tag, File, Config, User, Role, VerifiedEmail
 from pyrone.models.file import get_storage_dirs, get_backups_dir, allowed_dltypes
 
 log = logging.getLogger(__name__)
@@ -28,6 +30,7 @@ def view_settings(request):
     """
     c = dict(settings=dict(), errors=dict())
     for p in config.get_all():
+        log.debug(p.id)
         c['settings'][p.id] = p.value
     
     return c
@@ -67,7 +70,10 @@ def save_settings_ajax(request):
               'admin_notify_new_comment_subject_tpl', 'admin_notify_new_comment_body_tpl',
               'admin_notify_new_user_subject_tpl', 'admin_notify_new_user_body_tpl',
               'verification_msg_body_tpl', 'image_preview_width', 'google_analytics_id', 
-              'timezone', 'tw_consumer_key', 'tw_consumer_secret')
+              'timezone', 'tw_consumer_key', 'tw_consumer_secret', 'social_twitter_share_link',
+              'social_twitter_share_link_show_count', 'social_twitter_share_link_via', 
+              'social_gplusone')
+
         for id in settings:
             try:
                 v = request.POST[id]
@@ -75,15 +81,22 @@ def save_settings_ajax(request):
             except KeyError:
                 continue
 
-        bool_settings = ('admin_notify_new_comments', 'admin_notify_new_user')
+        bool_settings = ('admin_notify_new_comments', 
+            'admin_notify_new_user', 'social_twitter_share_link',
+            'social_twitter_share_link_show_count',
+            'social_gplusone')
         for id in bool_settings:
             if id in request.POST:
-                v = True
+                v = 'true'
             else:
-                v = False
+                v = 'false'
             config.set(id, v, dbsession)
 
         transaction.commit()
+
+        # refresh data in the cache
+        h.get_gplusone_button(True)
+        h.get_twitter_share_link_button(True)
     
     return c
 
@@ -273,12 +286,15 @@ def list_backups(request):
     c = dict(backups=list())
     
     backups_dir = get_backups_dir()
+    ind = 1
+
     for fn in os.listdir(backups_dir):
         full_fn = os.path.join(backups_dir, fn)
         if not os.path.isfile(full_fn):
             continue
-        br = dict(id=b64encode(fn), filename=fn, size=os.path.getsize(full_fn))
+        br = dict(id=ind, filename=fn, filename_b64=b64encode(fn), size=os.path.getsize(full_fn))
         c['backups'].append(br)
+        ind += 1
 
     c['backups'] = sorted(c['backups'])
     
@@ -335,7 +351,9 @@ def restore_backup(request):
     if root.tag != t('backup'):
         return dict(error=_('Unknown XML format of catalog file.'))
         
-    if root.get('version') != '1.0':
+    backup_version = root.get('version')
+
+    if backup_version not in ('1.0', '1.1'):
         return dict(error=_(u'Unsupported backup version: “%s”!' % root.get('version')))
 
     dbsession = DBSession()
@@ -346,7 +364,7 @@ def restore_backup(request):
     dbsession.query(Tag).delete()
     dbsession.query(Article).delete()
     dbsession.query(VerifiedEmail).delete()
-    dbsession.query(Permission).delete()
+    dbsession.query(Role).delete()
     dbsession.query(File).delete() # also remove files from the storage dir
     dbsession.query(Config).delete()
     dbsession.query(User).delete()
@@ -400,11 +418,25 @@ def restore_backup(request):
         
         dbsession.add(u)
         
-        # restore permissions now
-        subnodes = node.xpath('./b:permissions/b:permission', namespaces=namespaces)
-        for sn in subnodes:
-            p = Permission(None, u.id, sn.text)
-            dbsession.add(p)
+        if backup_version == '1.0':
+            # restore permissions now
+            permissions_roles_map = dict(write_article='writer', edit_article='editor',
+                admin='admin', files='filemanager')
+            subnodes = node.xpath('./b:permissions/b:permission', namespaces=namespaces)
+            for sn in subnodes:
+                permission_name = sn.text
+                if permission_name not in permissions_roles_map:
+                    continue
+
+                role_name = permissions_roles_map[permission_name]
+                r = Role(None, u.id, role_name)
+                dbsession.add(r)
+        elif backup_version == '1.1':
+            # restore roles directly
+            subnodes = node.xpath('./b:roles/b:role', namespaces=namespaces)
+            for sn in subnodes:
+                r = Role(None, u.id, sn.text)
+                dbsession.add(r)
             
     # restore verified emails
     nodes = xmldoc.xpath('//b:backup/b:verified-emails', namespaces=namespaces)
@@ -602,7 +634,7 @@ def backup_now(request):
         return node
     
     root = etree.Element('backup', nsmap=nsmap)
-    root.set('version', '1.0')
+    root.set('version', '1.1')
     
     info_el = e(root, 'info')
     articles_el = e(root, 'articles')
@@ -660,7 +692,7 @@ def backup_now(request):
         s = e(settings_el, 'config', setting.value)
         s.set('id', setting.id)
         
-    # dump users and permissions
+    # dump users and roles
     for user in dbsession.query(User).all():
         user_el = e(users_el, 'user')
         user_el.set('id', str(user.id))
@@ -669,10 +701,10 @@ def backup_now(request):
         e(user_el, 'display-name', user.display_name)
         e(user_el, 'email', user.email)
         e(user_el, 'kind', user.kind)
-        perms_el = e(user_el, 'permissions')
+        perms_el = e(user_el, 'roles')
         
-        for p in user.permissions:
-            e(perms_el, 'permission', p.name)
+        for p in user.roles:
+            e(perms_el, 'role', p.name)
         
     # dump files
     ind = 1
@@ -721,6 +753,41 @@ def backup_now(request):
     data['success'] = True
     return data
 
+@view_config(route_name='admin_download_backup')
+def download_backup(request):
+    encoded_filename = request.matchdict['backup_id']
+
+    headers = []
+
+    try:
+        filename = base64.b64decode(encoded_filename)
+    except TypeError:
+        return HTTPNotFound()
+
+    backups_dir = get_backups_dir()
+    all_backups = [x for x in os.listdir(backups_dir) if os.path.isfile(os.path.join(backups_dir, x))]
+    if filename not in all_backups:
+        return HTTPNotFound()        
+    
+    full_path = os.path.join(backups_dir, filename)
+    if not os.path.isfile(full_path):
+        return HTTPNotFound()
+
+    headers = []
+    content_length = os.path.getsize(full_path)
+    headers.append( ('Content-Length', str(content_length)) );
+    headers.append( ('Content-Disposition', 'attachment; filename=%s' % filename) )
+
+    response = Response(content_type='application/octet-stream')
+    try:
+        response.app_iter = open(full_path, 'rb')
+    except IOError:
+        return HTTPNotFound()
+
+    response.headerlist += headers
+
+    return response
+
 @view_config(route_name='admin_delete_backups_ajax', renderer='json', permission='admin')
 def delete_backups(request):
     c = dict(deleted=[])
